REPL (Read-Eval-Print Loop) module root for mongosh
This module is split into several submodules responsible for different aspects of the interactive shell:
cursor_state: pagination cursor stateshared_state: shared mutable state between REPL and execution contextengine:ReplEngine, the main interactive loop and editorcompleter: Completion provider for reedlinehighlighter: Syntax highlighting for reedlinehinter: Inline hints for reedlinevalidator: Line validation for reedlinecompletion: Intelligent completion system for MongoDB shell and SQL
External code should typically depend on ReplEngine and SharedState.
More specialized types (e.g. completer, highlighter, validator)
are re‑exported for convenience but are mostly internal details of the
REPL implementation.
Modules
- completion
- Completion system for mongosh REPL
Structs
- Cursor
State - Active cursor state for pagination
- Repl
Engine - REPL engine for interactive command execution
- Shared
State - Shared state between REPL and execution context.